# R-Script Experiment 1 (de la Vega et al. 2012, JEP:HPP)
# Author: Irmgard de la Vega

rm(list=ls(all=T))

Valenz <- read.table(choose.files(), header=T)

rownames(Valenz) <- NULL
Val1 <- Valenz <- Valenz[order(Valenz$Subject),]

# exclude practice trials
Val2 <- Val1[Val1$Procedure.Block. != "uebungneu"
 & Val1$Procedure.Block. != "uebungneu2", ]

# percentage errors?
Val2.1 <- Val2[Val2$wortnichtwort1.ACC == "1",]
PC <- (nrow(Val2.1)/nrow(Val2))*100

# exclude filler items
Val3 <- Val2[Val2$Valenz != "keine",]

# include only correct trials
Val4 <- Val3[Val3$wortnichtwort1.ACC == "1",]

# individual error rate
ValError    <- with(Val3, aggregate(wortnichtwort1.ACC != 1, list(Subject), mean))  
ValError$n  <- with(Val3, aggregate(wortnichtwort1.ACC == 1, list(Subject), sum))[,2]
View(ValError)

# subjects' age etc.
deskriptiv <- reshape(Val4, idvar=c("Subject","Age","Group","MutterspracheDeutsch", "Sex"), timevar=NULL, dir="wide")
summary(deskriptiv)

Val4$wortnichtwort1.RT <- as.numeric(as.character(Val4$wortnichtwort1.RT))
boxplot(Val4$wortnichtwort1.RT)
Val5 <- Val4[Val4$wortnichtwort1.RT >= 50 & Val4$wortnichtwort1.RT <= 2000, ]


# aggregate data for by-participants analysis
Val6 <- aggregate(Val5$wortnichtwort1.RT, list(Val5$Subject, Val5$ExperimentName, Val5$correcteAntwort, Val5$Valenz), mean)
names(Val6) <- c("Subject", "Version", "Hand", "Valence", "mRT")    
sapply(Val6, class)

Val6$Subject <- factor(Val6$Subject)
Val6$Valence <- factor(Val6$Valence, levels=c("negativ", "neutral", "positiv"))

aov1 <- aov(mRT ~ Valence * Hand * Version + Error(Subject/Valence*Hand),
   Val6)
summary(aov1)

with(Val6, interaction.plot(Valence, Hand, mRT))


# aggregate data for by-items analysis
Val7 <- aggregate(Val5$wortnichtwort1.RT, list(Val5$Stimulus, Val5$ExperimentName, Val5$correcteAntwort, Val5$Valenz), mean)
names(Val7) <- c("Stimulus", "Version", "Hand", "Valence", "mRT")
sapply(Val7, class)
str(Val7)
Val7$Valenz <- factor(Val7$Valence, levels=c("negativ", "neutral", "positiv"))
aov3 <- aov(mRT ~ Hand * Valence * Version + Error(Stimulus/Hand*Version),
   Val7)
summary(aov3)



# post-hoc analyses: by-participants
PosNeutr <- Val6[Val6$Valence != "negativ", ]
aovposneutr <- aov(mRT ~ Valence * Hand * Version + Error(Subject/Valence*Hand),
  PosNeutr)
summary(aovposneutr)

NeutrNeg <- Val6[Val6$Valence != "positiv", ]
aovneutrneg <- aov(mRT ~ Valence * Hand * Version + Error(Subject/Valence*Hand),
  NeutrNeg)
summary(aovneutrneg)

PosNeg <- Val6[Val6$Valence != "neutral", ]
aovposneg <- aov(mRT ~ Valence * Hand * Version + Error(Subject/Valence*Hand),
  PosNeg)
summary(aovposneg)

# post-hoc analyses: by-items
PosNeutrF2 <- Val7[Val7$Valenz != "negativ", ]
aovposneutrF2 <- aov(mRT ~ Valence * Hand * Version + Error(Stimulus/Hand*Version),
  PosNeutrF2)
summary(aovposneutrF2)

NeutrNegF2 <- Val7[Val7$Valenz != "positiv", ]
aovneutrnegF2 <- aov(mRT ~ Valence * Hand * Version + Error(Stimulus/Hand*Version),
  NeutrNegF2)
summary(aovneutrnegF2)

PosNegF2 <- Val7[Val7$Valenz != "neutral", ]
aovposnegF2 <- aov(mRT ~ Valence * Hand * Version + Error(Stimulus/Hand*Version),
  PosNegF2)
summary(aovposnegF2)



