# R-Script Experiment 2 (de la Vega et al. 2012, JEP:HPP)
# Author: Irmgard de la Vega


rm(list=ls(all=T))

Valenz <- read.table(choose.files(), header=T)
Val1 <- Valenz[order(Valenz$Subject),]

# # subjects' age etc.
deskriptiv <- reshape(Val1, idvar=c("Subject","Age","Group","Handedness", "MutterspracheDeutsch", "Sex"), timevar=NULL, dir="wide")
summary(deskriptiv)

# exclude practice trials
Val2 <- Val1[Val1$Procedure.Block != "uebungneu" & Val1$Procedure.Block != "uebungneu2", ]

# exclude filler items
Val3 <- Val2[Val2$Valenz != "keine", ]

# only correct trials
Val4 <- Val3[Val3$wortnichtwort1.ACC == "1", ]
# percentage errors?
nrow(Val4)/nrow(Val3) * 100 

# individual error rate in go-trials
ValError    <- with(Val3, aggregate(wortnichtwort1.ACC != 1, list(Subject), mean))  
ValError$n  <- with(Val3, aggregate(wortnichtwort1.ACC == 1, list(Subject), sum))[,2]
View(ValError)

# exclude Subject no. 11 due to high error rate (> or = 10%) in go-trials
Val4 <- Val4[Val4$Subject != "11",]

# exclude outliers
Val4 <- Val4[Val4$wortnichtwort1.RT >= 50 & Val4$wortnichtwort1.RT <= 2000, ]

# aggregate data for by-participants analysis
Val6 <- aggregate(Val4$wortnichtwort1.RT, list(Val4$ExperimentName, Val4$Subject, Val4$Valenz, Val4$correcteAntwort), mean)
names(Val6) <- c("Version", "Subject", "Valence", "Hand", "mRT")

Val7 <- Val6[order(Val6$Subject),]
rownames(Val7) <- NULL

Val7$Version <- factor(Val7$Version)
Val7$Subject <- factor(Val7$Subject)
Val7$Valence <- factor(Val7$Valence)
Val7$Hand <- factor(Val7$Hand)

with(Val7, interaction.plot(Valence,Hand,mRT))

aov1 <- aov(mRT ~ Valence*Hand*Version + Error(Subject/(Valence*Hand)), Val7)
summary(aov1)

# post-hoc analyses
positiv <- Val7[Val7$Valence == "positiv", ]
negativ <- Val7[Val7$Valence == "negativ", ]

aovpos <- aov(mRT ~ Hand*Version + Error(Subject/(Hand)), positiv)
summary(aovpos)

aovneg <- aov(mRT ~ Hand*Version + Error(Subject/(Hand)), negativ)
summary(aovneg)

# aggregate data for by-items analysis
Val8 <- aggregate(Val4$wortnichtwort1.RT, list(Val4$ExperimentName, Val4$Stimulus, Val4$Valenz, Val4$correcteAntwort), mean)
names(Val8) <- c("Version", "Stimulus", "Valence", "Hand", "mRT")

Val8 <- Val8[order(Val8$Stimulus),]
rownames(Val8) <- NULL

Val8$Version <- factor(Val8$Version)
Val8$Stimulus <- factor(Val8$Stimulus)
Val8$Valence <- factor(Val8$Valence)
Val8$Hand <- factor(Val8$Hand)

with(Val8, interaction.plot(Valence,Hand,mRT))

aov2 <- aov(mRT ~ Valence*Hand*Version + Error(Stimulus/(Hand*Version)), Val8)
summary(aov2)

# post-hoc analyses
positivF2 <- Val8[Val8$Valence == "positiv", ]
negativF2 <- Val8[Val8$Valence == "negativ", ]

aovposF2 <- aov(mRT ~ Hand*Version + Error(Stimulus/(Hand*Version)), positivF2)
summary(aovposF2)

aovnegF2 <- aov(mRT ~ Hand*Version + Error(Stimulus/(Hand*Version)), negativF2)
summary(aovnegF2)