# R-Script Experiment 4 (de la Vega et al. 2012, JEP:HPP)
# Author: Irmgard de la Vega

# Note: the numbering of participants is not continuous - 
# participant numbers range from 1-32 and from 40-48


rm(list=ls(all=T))

Valenz <- read.table(choose.files(), header=T)

# exclusion of one participant (score handedness < +40); had been replaced
# by other participant
Valenz <- Valenz[Valenz$Subject != "26",]

rownames(Valenz) <- NULL
Val1 <- Valenz <- Valenz[order(Valenz$Subject),]

# exclude practice trials
Val2 <- Val1[Val1$Procedure.Block. != "uebungneu"
 & Val1$Procedure.Block. != "uebungneu2"
 & Val1$Procedure.Block. != "uebung3"
 & Val1$Procedure.Block. != "uebung4", ]

# exclude no-gos
Val3 <- Val2[Val2$Slide1.RESP != "X",]

# only correct trials
Val4 <- Val3[Val3$Slide1.ACC == "1",]

# Errors
Val2.1 <- Val2[Val2$Slide1.ACC == "1",]
ErrorsAll <- (nrow(Val2.1)/nrow(Val2))*100
ErroraGo <- (nrow(Val4)/nrow(Val3))*100


ValFehler    <- with(Val2, aggregate(Slide1.ACC != 1, list(Subject), mean))  # fr Fehler
ValFehler$n  <- with(Val2, aggregate(Slide1.ACC == 1, list(Subject), sum))[,2]
View(ValFehler)

# exclusion of participants due to high error rate (> or = 10%)
Val4 <- Val4[Val4$Subject != "28" & Val4$Subject != "42",]


# subjects' age etc.
deskriptiv <- reshape(Val4, idvar=c("Subject","Age","Group","MutterspracheDeutsch", "Sex"), timevar=NULL, dir="wide")
summary(deskriptiv)

Val4$Slide1.RT <- as.numeric(as.character(Val4$Slide1.RT))
boxplot(Val4$Slide1.RT)

# exclude outliers
Val5 <- Val4[Val4$Slide1.RT >= 50 & Val4$Slide1.RT <= 2000, ]

# aggregate data for by-participants analysis
Val6 <- aggregate(Val5$Slide1.RT, list(Val5$Subject, Val5$ExperimentName, Val5$correcteAntwort, Val5$Valenz), mean)
names(Val6) <- c("Subject", "Version", "Hand", "Valence", "mRT")

sapply(Val6, class)

Val6$Subject <- factor(Val6$Subject)
Val6$Hand <- factor(Val6$Hand, levels=c("9", "q"))

aov1 <- aov(mRT ~ Valence * Hand * Version + Error(Subject/Valence*Hand),
   Val6)
summary(aov1)

with(Val6, interaction.plot(Valence, Hand, mRT))


# aggregate data for by-items analysis
Val7 <- aggregate(Val5$Slide1.RT, list(Val5$Stimulus, Val5$ExperimentName,
                  Val5$correcteAntwort, Val5$Valenz), mean)
names(Val7) <- c("Stimulus", "Version", "Hand", "Valence", "mRT")

Val7$Hand <- factor(Val7$Hand, levels=c("9", "q"))

aov2 <- aov(mRT ~ Valence * Hand * Version + Error(Stimulus/Hand*Version),
   Val7)
summary(aov2)

